@@ -8,10 +8,11 @@ eggs = pelican, pelican-gist
 links = http://github.com/toumorokoshi/sprinter/tarball/master#egg=sprinter-0.6
 redownload = true
 """
+from __future__ import unicode_literals
 import os
 import re
 
-from sprinter import lib
+import sprinter.lib as lib
 from sprinter.formulabase import FormulaBase
 from sprinter.virtualenv import create_environment as create_virtualenv
 
